# shine.validation.plots

Diagnostic plots for bias measurement.

Generates trace plots, marginal posterior histograms, pair plots,
and (future) bias regression and coverage visualizations.

::: shine.validation.plots
